@@ -21,12 +21,7 @@ signer <- function(x, y) {
 ## Make syuzhet dictionaries into sentimentr keys
 bing <- as_key(syuzhet:::bing)
 afinn <- as_key(syuzhet:::afinn)
-nrc <- data.frame(
-    words = rownames(syuzhet:::nrc),
-    polarity = syuzhet:::nrc[, "positive"] - syuzhet:::nrc[, "negative"],
-    stringsAsFactors = FALSE
-) %>%
-    {as_key(.[.[["polarity"]] != 0, ])}
+nrc <- lexicon::hash_sentiment_nrc
 
 syuzhet_dict <- as_key(syuzhet:::syuzhet_dict)
 
